@@ -203,28 +203,28 @@ def create_merchant_customer_reward_reverted_upstream_for_merchant(transaction_d
                       streamed_datetime=reverted_datetime, Reverted=True, RevertedDateTime=reverted_datetime)    
 
 
-def create_merchant_customer_redemption_upstream_for_merchant(redemption_details, streamed_datetime=None):
+def create_merchant_customer_redemption_upstream_for_merchant(customer_redemption, streamed_datetime=None):
     if streamed_datetime is None:
         streamed_datetime     = datetime.now() - timedelta(hours=int(conf.SERVER_DATETIME_GMT))
     
-    logger.debug('redemption_details.merchant_acct=%s', redemption_details.merchant_acct)
+    logger.debug('customer_redemption.merchant_acct=%s', customer_redemption.merchant_acct)
     
     table_name          = MERCHANT_CUSTOMER_REDEMPTION_TEMPLATE
-    merchant_acct       = redemption_details.redeemed_merchant_acct
+    merchant_acct       = customer_redemption.redeemed_merchant_acct
     account_code        = merchant_acct.account_code.replace('-','')
     final_table_name    = '{}_{}_{}'.format(table_name, account_code, streamed_datetime.strftime('%Y%m%d'))
     
     upstream_data_list = []
     
-    transaction_id      = redemption_details.transaction_id
-    redeemed_outlet_key = redemption_details.redeemed_outlet_key
-    merchant_key        = redemption_details.redeemed_merchant_acct_key
-    customer_key        = redemption_details.redeemed_customer_key
-    redeemed_amount     = redemption_details.redeemed_amount
-    reward_format       = redemption_details.reward_format
-    redeemed_datetime   = redemption_details.redeemed_datetime
+    transaction_id      = customer_redemption.transaction_id
+    redeemed_outlet_key = customer_redemption.redeemed_outlet_key
+    merchant_key        = customer_redemption.redeemed_merchant_acct_key
+    customer_key        = customer_redemption.redeemed_customer_key
+    redeemed_amount     = customer_redemption.redeemed_amount
+    reward_format       = customer_redemption.reward_format
+    redeemed_datetime   = customer_redemption.redeemed_datetime
     
-    for reward_format, details in redemption_details.redeemed_summary.items():
+    for reward_format, redemption_details in customer_redemption.redeemed_summary.items():
         if reward_format in (program_conf.REWARD_FORMAT_POINT, program_conf.REWARD_FORMAT_STAMP):
             upstream_data_list.append(CustomerRedeemedItemUpstream(
                                         customer_key        = customer_key,
@@ -238,7 +238,7 @@ def create_merchant_customer_redemption_upstream_for_merchant(redemption_details
                                         
                                     ))
         else:
-            for voucher_key, voucher_count in details.items():
+            for voucher_key, voucher_count in redemption_details.get('vouchers').items():
                 upstream_data_list.append(CustomerRedeemedItemUpstream(
                                         customer_key        = customer_key,
                                         merchant_key        = merchant_key,
